@@ -210,7 +210,7 @@ ui_itemlist_update_iter (GtkTreeIter *iter,
 
 	/* Label and state icon */
 	if(!item->title || !strlen(item->title)) {
-		esc_title = g_strdup(_("<i>*** No title ***</i>"));
+		esc_title = g_strdup(_("*** No title ***"));
 	} else {
 		/* we escape here to use Pango markup (the parsing ensures that
 		   titles never contain escaped HTML) */
@@ -596,7 +596,11 @@ void ui_itemlist_select(itemPtr item) {
 		GtkTreeIter		iter;
 		GtkTreePath		*path;
 		
-		g_return_if_fail(ui_item_id_to_iter(item->id, &iter));
+		if(!ui_item_id_to_iter(item->id, &iter))
+			/* This is an evil hack to fix SF #1870052: crash
+			   upon hitting <enter> when no headline selected.
+			   FIXME: This code is rotten! Rewrite it! Now! */
+			itemlist_selection_changed(NULL);
 
 		treeview = itemlist_treeview;
 		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
@@ -610,28 +614,6 @@ void ui_itemlist_select(itemPtr item) {
 	}
 }
 
-static itemPtr
-ui_itemlist_find_unread_item_from_iter (GtkTreeIter *iter)
-{
-	itemPtr	item;
-	
-	item = item_load (ui_iter_to_item_id (iter));
-	if (item) {
-		if (!item->readStatus) {
-			if (2 != itemlist_get_view_mode ()) {	// FIXME: 2
-				ui_itemlist_select(item);
-				item_state_set_read (item, TRUE);	/* needed when no selection happens (e.g. when the item is already selected) */
-			} else {
-				item_state_set_all_read (node_from_id (item->nodeId));
-			}
-			return item;
-		}
-		item_unload (item);
-	}
-	
-	return NULL;
-}
-
 itemPtr ui_itemlist_find_unread_item(gulong startId) {
 	GtkTreeStore		*itemstore;
 	GtkTreeIter		iter;
@@ -646,9 +628,12 @@ itemPtr ui_itemlist_find_unread_item(gulong startId) {
 	
 	while(valid) {
 		itemPtr	item;
-		item = ui_itemlist_find_unread_item_from_iter(&iter);
-		if(item)
-			return item;
+		item = item_load (ui_iter_to_item_id (&iter));
+		if (item) {
+			if (!item->readStatus)
+				return item;
+			item_unload (item);
+		}
 		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(itemstore), &iter);
 	}
 
@@ -765,16 +750,18 @@ on_popup_social_bm_link_selected (gpointer selectedUrl, guint callback_action, G
 	}
 }
 
-void on_itemlist_selection_changed(GtkTreeSelection *selection, gpointer data) {
+void
+on_itemlist_selection_changed (GtkTreeSelection *selection, gpointer data)
+{
 	GtkTreeIter 	iter;
 	GtkTreeModel	*model;
 	itemPtr		item = NULL;
 
-	if(gtk_tree_selection_get_selected(selection, &model, &iter))
-		item = item_load(ui_iter_to_item_id(&iter));
+	if (gtk_tree_selection_get_selected (selection, &model, &iter))
+		item = item_load (ui_iter_to_item_id (&iter));
 
-	if(item)
-		itemlist_selection_changed(item);
+	if (item)
+		itemlist_selection_changed (item);
 }
 
 void itemlist_sort_column_changed_cb(GtkTreeSortable *treesortable, gpointer user_data) {
